function readCookie(key) {
  const re = new RegExp(key + '=([^;]+)')
  const value = re.exec(document.cookie)
  return value !== null ? unescape(value[1]) : null
}

function getVisitorId() {
  if (window.__mpi.visitorId) return Promise.resolve(window.__mpi.visitorId)

  return new Promise(function(resolve) {
    function retry(retries) {
      if (retries === 0) {
        return resolve('')
      }

      const visitorId = readCookie('IJ_MCMID')
      if (visitorId) {
        window.__mpi.visitorId = visitorId
        return resolve(visitorId)
      }

      window.setTimeout(function() {
        retry(--retries)
      }, 50)
    }
    retry(500)
  })
}

export const setupSegmentWrapperConfig = () => {
  function getSite() {
    return window.location.host.indexOf('infojobs.it') > -1
      ? 'infojobs.it'
      : 'infojobs.net'
  }

  window.__mpi = {
    segmentWrapper: {
      facebookPixelId: 283351338713870,
      googleAdsPixelId: 1024323628,
      defaultProperties: {
        site: getSite()
      },
      getCustomAdobeVisitorId: getVisitorId,
      tcfTrackDefaultProperties: {
        vertical: 'jobs'
      }
    }
  }
}
